@@ -110,7 +110,7 @@ class S3PreparedRequest(requests.models.PreparedRequest):
                 if not value:
                     continue
                 header_key = 'x-archive-meta{0:02d}-{1}'.format(i, meta_key)
-                if any(c in value for c in ['\n', '\r']):
+                if any(c in str(value) for c in ['\n', '\r']):
                     value = 'uri({0})'.format(urllib.parse.quote(value))
                 # because rfc822 http headers disallow _ in names, IA-S3 will
                 # translate two hyphens in a row (--) into an underscore (_).
