@@ -2,6 +2,7 @@ import os
 import sys
 from fnmatch import fnmatch
 import logging
+import time
 
 import requests.sessions
 from requests.adapters import HTTPAdapter
@@ -316,7 +317,8 @@ class Item(object):
     def upload_file(self, body, key=None, metadata={}, headers={},
                     access_key=None, secret_key=None, queue_derive=True,
                     ignore_preexisting_bucket=False, verbose=False, verify=True,
-                    checksum=False, delete=False, debug=False, **kwargs):
+                    checksum=False, delete=False, retries=0, retries_sleep=20, 
+                    debug=False, **kwargs):
         """Upload a single file to an item. The item will be created
         if it does not exist.
 
@@ -351,6 +353,14 @@ class Item(object):
         :param delete: (optional) Delete local file after the upload has been
                        successfully verified.
 
+        :type retries: int
+        :param retries: (optional) Number of times to retry the given request
+                        if S3 returns a 503 SlowDown error.
+
+        :type retries_sleep: int
+        :param retries_sleep: (optional) Amount of time to sleep between 
+                              ``retries``.
+
         :type verbose: bool
         :param verbose: (optional) Print progress to stdout.
 
@@ -412,38 +422,63 @@ class Item(object):
         # require the Content-MD5 header when delete is True.
         if verify or delete:
             headers['Content-MD5'] = md5_sum
-        if verbose:
-            try:
-                chunk_size = 1048576
-                expected_size = size/chunk_size + 1
-                chunks = utils.chunk_generator(body, chunk_size)
-                progress_generator = progress.bar(chunks, expected_size=expected_size,
-                                                  label=' uploading {f}: '.format(f=key))
-                data = utils.IterableToFileAdapter(progress_generator, size)
-            except:
-                sys.stdout.write(' uploading {f}: '.format(f=key))
-                data = body
-        else:
-            data = body
 
-        request = iarequest.S3Request(
-            method='PUT',
-            url=url,
-            headers=headers,
-            data=data,
-            metadata=metadata,
-            access_key=access_key,
-            secret_key=secret_key,
-            queue_derive=queue_derive,
-            **kwargs
-        )
+        # Delete retries and sleep_retries from kwargs.
+        if 'retries' in kwargs:
+            del kwargs['retries']
+        if 'retries_sleep' in kwargs:
+            del kwargs['retries_sleep']
+
+        def _build_request():
+            body.seek(0, os.SEEK_SET)
+            if verbose:
+                try:
+                    chunk_size = 1048576
+                    expected_size = size/chunk_size + 1
+                    chunks = utils.chunk_generator(body, chunk_size)
+                    progress_generator = progress.bar(chunks, expected_size=expected_size,
+                                                      label=' uploading {f}: '.format(f=key))
+                    data = utils.IterableToFileAdapter(progress_generator, size)
+                except:
+                    sys.stdout.write(' uploading {f}: '.format(f=key))
+                    data = body
+            else:
+                data = body
+
+            request = iarequest.S3Request(
+                method='PUT',
+                url=url,
+                headers=headers,
+                data=data,
+                metadata=metadata,
+                access_key=access_key,
+                secret_key=secret_key,
+                queue_derive=queue_derive,
+                **kwargs
+            )
+            return request
 
         if debug:
-            return request
+            return _build_request()
         else:
-            prepared_request = request.prepare()
             try:
-                response = self.http_session.send(prepared_request, stream=True)
+                while True:
+                    request = _build_request()
+                    prepared_request = request.prepare()
+                    response = self.http_session.send(prepared_request, stream=True)
+                    if (response.status_code == 503) and (retries > 0):
+                        error_msg = ('s3 is overloaded, sleeping for '
+                                     '{0} seconds and retrying. '
+                                     '{1} retries left.'.format(retries_sleep, retries))
+                        log.info(error_msg)
+                        sys.stderr.write(' warning: {0}\n'.format(error_msg))
+                        time.sleep(retries_sleep)
+                        retries -= 1
+                        continue
+                    else:
+                        if response.status_code == 503:
+                            log.info('maximum retries exceeded, upload failed.')
+                        break
                 response.raise_for_status()
                 log.info('uploaded {f} to {u}'.format(f=key, u=url))
                 if delete and response.status_code == 200:
